@@ -1,11 +1,14 @@
 import os
 
 import yaml
+import pytest
+
 from ddb.__main__ import main
 from tests.utilstest import expect_gitignore, setup_cfssl
 
 
 class TestEject:
+    @pytest.mark.docker
     def test_eject1(self, project_loader, module_scoped_container_getter):
         project_loader("eject1")
 
@@ -15,25 +18,25 @@ class TestEject:
 
         assert os.path.exists("docker-compose.yml")
         assert os.path.exists("docker-compose.yml.jsonnet")
-        assert expect_gitignore(".gitignore", "docker-compose.yml")
+        assert expect_gitignore(".gitignore", "/docker-compose.yml")
 
-        assert os.path.exists(os.path.join(".bin", "psql"))
-        assert expect_gitignore(".gitignore", ".bin/psql")
+        assert os.path.exists(os.path.join(".bin", "psql" + (".bat" if os.name == "nt" else "")))
+        assert expect_gitignore(".gitignore", "/.bin/psql" + (".bat" if os.name == "nt" else ""))
 
         assert os.path.exists(os.path.join(".docker", "db", "Dockerfile.jinja"))
-        assert expect_gitignore(".gitignore", ".docker/db/Dockerfile")
+        assert expect_gitignore(".gitignore", "/.docker/db/Dockerfile")
 
         main(["configure", "--eject"])
 
         assert os.path.exists("docker-compose.yml")
         assert not os.path.exists("docker-compose.yml.jsonnet")
-        assert not expect_gitignore(".gitignore", "docker-compose.yml")
+        assert not expect_gitignore(".gitignore", "/docker-compose.yml")
 
-        assert os.path.exists(os.path.join(".bin", "psql"))
-        assert expect_gitignore(".gitignore", ".bin/psql")
+        assert os.path.exists(os.path.join(".bin", "psql" + (".bat" if os.name == "nt" else "")))
+        assert expect_gitignore(".gitignore", "/.bin/psql" + (".bat" if os.name == "nt" else ""))
 
         assert not os.path.exists(os.path.join(".docker", "db", "Dockerfile.jinja"))
-        assert not expect_gitignore(".gitignore", ".docker/db/Dockerfile")
+        assert not expect_gitignore(".gitignore", "/.docker/db/Dockerfile")
 
         with open('docker-compose.yml', 'r') as dc_file:
             data = yaml.load(dc_file, yaml.SafeLoader)
@@ -43,6 +46,7 @@ class TestEject:
 
         assert data == expected_data
 
+    @pytest.mark.docker
     def test_eject2(self, project_loader, module_scoped_container_getter):
         project_loader("eject2")
 
@@ -52,25 +56,25 @@ class TestEject:
 
         assert os.path.exists("docker-compose.yml")
         assert os.path.exists("docker-compose.yml.jsonnet")
-        assert expect_gitignore(".gitignore", "docker-compose.yml")
+        assert expect_gitignore(".gitignore", "/docker-compose.yml")
 
-        assert os.path.exists(os.path.join(".bin", "psql"))
-        assert expect_gitignore(".gitignore", ".bin/psql")
+        assert os.path.exists(os.path.join(".bin", "psql" + (".bat" if os.name == "nt" else "")))
+        assert expect_gitignore(".gitignore", "/.bin/psql" + (".bat" if os.name == "nt" else ""))
 
         assert os.path.exists(os.path.join(".docker", "db", "Dockerfile.jinja"))
-        assert expect_gitignore(".gitignore", ".docker/db/Dockerfile")
+        assert expect_gitignore(".gitignore", "/.docker/db/Dockerfile")
 
         main(["configure", "--eject"])
 
         assert os.path.exists("docker-compose.yml")
         assert not os.path.exists("docker-compose.yml.jsonnet")
-        assert not expect_gitignore(".gitignore", "docker-compose.yml")
+        assert not expect_gitignore(".gitignore", "/docker-compose.yml")
 
-        assert os.path.exists(os.path.join(".bin", "psql"))
-        assert expect_gitignore(".gitignore", ".bin/psql")
+        assert os.path.exists(os.path.join(".bin", "psql" + (".bat" if os.name == "nt" else "")))
+        assert expect_gitignore(".gitignore", "/.bin/psql" + (".bat" if os.name == "nt" else ""))
 
         assert not os.path.exists(os.path.join(".docker", "db", "Dockerfile.jinja"))
-        assert not expect_gitignore(".gitignore", ".docker/db/Dockerfile")
+        assert not expect_gitignore(".gitignore", "/.docker/db/Dockerfile")
 
         with open('docker-compose.yml', 'r') as dc_file:
             data = yaml.load(dc_file, yaml.SafeLoader)
@@ -80,6 +84,7 @@ class TestEject:
 
         assert data == expected_data
 
+    @pytest.mark.docker
     def test_eject2_with_jsonnet_disabled(self, project_loader, module_scoped_container_getter):
         project_loader("eject2")
 
@@ -89,27 +94,27 @@ class TestEject:
 
         assert os.path.exists("docker-compose.yml")
         assert os.path.exists("docker-compose.yml.jsonnet")
-        assert expect_gitignore(".gitignore", "docker-compose.yml")
+        assert expect_gitignore(".gitignore", "/docker-compose.yml")
 
-        assert os.path.exists(os.path.join(".bin", "psql"))
-        assert expect_gitignore(".gitignore", ".bin/psql")
+        assert os.path.exists(os.path.join(".bin", "psql" + (".bat" if os.name == "nt" else "")))
+        assert expect_gitignore(".gitignore", "/.bin/psql" + (".bat" if os.name == "nt" else ""))
 
         assert os.path.exists(os.path.join(".docker", "db", "Dockerfile.jinja"))
-        assert expect_gitignore(".gitignore", ".docker/db/Dockerfile")
+        assert expect_gitignore(".gitignore", "/.docker/db/Dockerfile")
 
-        os.environ['DDB_OVERRIDE_DOCKER_JSONNET_VIRTUALHOST_DISABLED'] = "1"
-        os.environ['DDB_OVERRIDE_DOCKER_JSONNET_BINARY_DISABLED'] = "True"
+        os.environ['DDB_OVERRIDE_JSONNET_DOCKER_VIRTUALHOST_DISABLED'] = "1"
+        os.environ['DDB_OVERRIDE_JSONNET_DOCKER_BINARY_DISABLED'] = "True"
         main(["configure", "--eject"])
 
         assert os.path.exists("docker-compose.yml")
         assert not os.path.exists("docker-compose.yml.jsonnet")
-        assert not expect_gitignore(".gitignore", "docker-compose.yml")
+        assert not expect_gitignore(".gitignore", "/docker-compose.yml")
 
-        assert not os.path.exists(os.path.join(".bin", "psql"))
-        assert not expect_gitignore(".gitignore", ".bin/psql")
+        assert not os.path.exists(os.path.join(".bin", "psql" + (".bat" if os.name == "nt" else "")))
+        assert not expect_gitignore(".gitignore", "/.bin/psql" + (".bat" if os.name == "nt" else ""))
 
         assert not os.path.exists(os.path.join(".docker", "db", "Dockerfile.jinja"))
-        assert not expect_gitignore(".gitignore", ".docker/db/Dockerfile")
+        assert not expect_gitignore(".gitignore", "/.docker/db/Dockerfile")
 
         with open('docker-compose.yml', 'r') as dc_file:
             data = yaml.load(dc_file, yaml.SafeLoader)
